summaryrefslogtreecommitdiff
path: root/chip/stm32/adc_chip.h
diff options
context:
space:
mode:
Diffstat (limited to 'chip/stm32/adc_chip.h')
-rw-r--r--chip/stm32/adc_chip.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/chip/stm32/adc_chip.h b/chip/stm32/adc_chip.h
index 18a280a9d8..8cd53a748a 100644
--- a/chip/stm32/adc_chip.h
+++ b/chip/stm32/adc_chip.h
@@ -49,7 +49,7 @@ struct adc_t {
#if defined(CHIP_FAMILY_STM32F0) || defined(CHIP_FAMILY_STM32L4) || \
defined(CHIP_FAMILY_STM32L5)
- enum stm32_adc_smpr sample_rate; /* Sampling Rate of the channel */
+ enum stm32_adc_smpr sample_time; /* Sampling Time of the channel */
#endif
};